@@ -4,7 +4,7 @@ use Moo;
 
 use namespace::autoclean;
 
-our $VERSION = '0.000025';
+our $VERSION = '0.000026';
 
 use feature qw( say state );
 
@@ -15,8 +15,17 @@ use MooX::StrictConstructor;
 use Type::Params qw( compile );
 use Types::Common::Numeric qw( PositiveNum );
 use Types::Common::String qw( NonEmptyStr );
-use Types::Standard
-    qw( ArrayRef Bool CodeRef HashRef InstanceOf Int Num Optional );
+use Types::Standard qw(
+    ArrayRef
+    Bool
+    CodeRef
+    Defined
+    HashRef
+    InstanceOf
+    Int
+    Num
+    Optional
+);
 use Types::URI qw( Uri );
 use URI;
 use URI::FromHash qw( uri uri_object );
@@ -61,7 +70,7 @@ has partner => (
 
 has password => (
     is       => 'ro',
-    isa      => NonEmptyStr,
+    isa      => Defined,
     required => 1,
 );
 
@@ -85,7 +94,7 @@ has production_mode => (
 
 has user => (
     is       => 'ro',
-    isa      => NonEmptyStr,
+    isa      => Defined,
     required => 1,
 );
 
@@ -215,7 +224,7 @@ sub get_response_from_silent_post {
     # instantiation will not provide an IP address.
 
     my $class_suffix = 'Response::FromSilentPOST';
-    my $response = $self->_response_for( $class_suffix, %{$args} );
+    my $response     = $self->_response_for( $class_suffix, %{$args} );
 
     $class_suffix
         .= '::'
@@ -439,15 +448,13 @@ sub _pseudo_encode_args {
 
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 WebService::PayPal::PaymentsAdvanced - A simple wrapper around the PayPal Payments Advanced web service
 
 =head1 VERSION
 
-version 0.000025
+version 0.000026
 
 =head1 SYNOPSIS
 
@@ -789,10 +796,6 @@ Returns a response object.
 The official L<Payflow Gateway Developer Guide and
 Reference|https://developer.paypal.com/docs/classic/payflow/integration-guide/>
 
-=head1 SUPPORT
-
-Bugs may be submitted through L<https://github.com/maxmind/webservice-paypal-paymentsadvanced/issues>.
-
 =head1 AUTHOR
 
 Olaf Alders <olaf@wundercounter.com>
@@ -839,7 +842,7 @@ William Storey <wstorey@maxmind.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by MaxMind, Inc.
+This software is copyright (c) 2020 by MaxMind, Inc.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
